@@ -60,7 +60,7 @@ loader_rt_info_handler(const char *fmt, va_list ap) {
 	va_end(ap);
 }
 
-static void 
+static void
 rt_init_allocators(void) {
 	rt_set_handlers(
 		default_rt_allocator,
@@ -384,7 +384,7 @@ usage() {
 	));
 	printf(_(
 		"  -l <overview factor> Create overview of the raster. For more than\n"
-		"      one factor, separate with comma(,). Overview table name follows\n" 
+		"      one factor, separate with comma(,). Overview table name follows\n"
 		"      the pattern o_<overview factor>_<table>. Created overview is\n"
 		"      stored in the database and is not affected by -R.\n"
 	));
@@ -511,7 +511,7 @@ static void
 init_rastinfo(RASTERINFO *info) {
 	info->srid = SRID_UNKNOWN;
 	info->srs = NULL;
-	memset(info->dim, 0, sizeof(double) * 2);
+	memset(info->dim, 0, sizeof(uint32_t) * 2);
 	info->nband_count = 0;
 	info->nband = NULL;
 	info->gdalbandtype = NULL;
@@ -1229,7 +1229,7 @@ add_raster_constraints(
 		(regular_blocking ? "TRUE" : "FALSE"),
 		(max_extent ? "TRUE" : "FALSE")
 	);
-	
+
 	if (_schema != NULL)
 		rtdealloc(_schema);
 	rtdealloc(_table);
@@ -1330,7 +1330,7 @@ add_overview_constraints(
 		_column,
 		factor
 	);
-	
+
 	if (_ovschema != NULL)
 		rtdealloc(_ovschema);
 	rtdealloc(_ovtable);
@@ -1734,7 +1734,7 @@ convert_raster(int idx, RTLOADERCFG *config, RASTERINFO *info, STRINGBUFFER *til
 	/* number of tiles */
 	if (info->tile_size[0] != info->dim[0])
 		ntiles[0] = (info->dim[0] + info->tile_size[0]  - 1) / info->tile_size[0];
-	if (info->tile_size[1] != info->dim[1]) 
+	if (info->tile_size[1] != info->dim[1])
 		ntiles[1] = (info->dim[1] + info->tile_size[1]  - 1) / info->tile_size[1];
 
 	/* estimate size of 1 tile */
@@ -2280,15 +2280,14 @@ main(int argc, char **argv) {
 	GDALDriverH drv = NULL;
 	char *tmp = NULL;
 
+	rt_init_allocators();
+
 #ifdef USE_NLS
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, LOCALEDIR);
 	textdomain (PACKAGE);
 #endif
 
-	/* Set up memory handling */
-	rt_init_allocators();
-
 	/* no args, show usage */
 	if (argc == 1) {
 		usage();
@@ -2318,7 +2317,7 @@ main(int argc, char **argv) {
 				sscanf(optarg, "%d", &config->srid);
 				sscanf(ptr, "%d", &config->out_srid);
 			} else {
-				config->srid = config->out_srid = atoi(optarg);
+				config->srid = atoi(optarg);
 			}
 		}
 		/* band index */
@@ -2649,15 +2648,11 @@ main(int argc, char **argv) {
 		}
 	}
 
-	if (config->srid != config->out_srid) {
+	if (config->srid != config->out_srid && config->out_srid != SRID_UNKNOWN) {
 		if (config->copy_statements) {
 			rterror(_("Invalid argument combination - cannot use -Y with -s FROM_SRID:TO_SRID"));
 			exit(1);
 		}
-		if (config->out_srid == SRID_UNKNOWN) {
-			rterror(_("Unknown target SRID is invalid when source SRID is given"));
-			exit(1);
-		}
 	}
 
 	/* register GDAL drivers */
